



if not exist %LIBRARY_BIN%\\ziptool.exe exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\zip.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\zip.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\zipconf.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
